summaryrefslogtreecommitdiff
path: root/src/Spatial_searching/include
diff options
context:
space:
mode:
authorcjamin <cjamin@636b058d-ea47-450e-bf9e-a15bfbe3eedb>2016-09-22 13:35:38 +0000
committercjamin <cjamin@636b058d-ea47-450e-bf9e-a15bfbe3eedb>2016-09-22 13:35:38 +0000
commit3d2205afe247f23cbe69b98845569708b4263f02 (patch)
treeb507f34ce178bbe8bc994fb01587ad5852a46414 /src/Spatial_searching/include
parentaa994dbd8dadfd4be416f13b13721e7e13c3623a (diff)
Spatial_tree_data_structure => Kd_tree_search
git-svn-id: svn+ssh://scm.gforge.inria.fr/svnroot/gudhi/branches/subsampling_and_spatialsearching@1538 636b058d-ea47-450e-bf9e-a15bfbe3eedb Former-commit-id: 095b038d0e4c1c6d78e9aa9efe73447b65dab2b1
Diffstat (limited to 'src/Spatial_searching/include')
-rw-r--r--src/Spatial_searching/include/gudhi/Kd_tree_search.h (renamed from src/Spatial_searching/include/gudhi/Spatial_tree_data_structure.h)12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/Spatial_searching/include/gudhi/Spatial_tree_data_structure.h b/src/Spatial_searching/include/gudhi/Kd_tree_search.h
index 68702b22..af85915a 100644
--- a/src/Spatial_searching/include/gudhi/Spatial_tree_data_structure.h
+++ b/src/Spatial_searching/include/gudhi/Kd_tree_search.h
@@ -40,13 +40,13 @@ namespace spatial_searching {
/**
- * \class Spatial_tree_data_structure Spatial_tree_data_structure.h gudhi/Spatial_tree_data_structure.h
+ * \class Kd_tree_search Kd_tree_search.h gudhi/Kd_tree_search.h
* \brief Spatial tree data structure to perform (approximate) nearest neighbor search.
*
* \ingroup spatial_searching
*
* \details
* The class Spatial_tree_data_structure is a tree-based data structure, based on
* <a target="_blank" href="http://doc.cgal.org/latest/Spatial_searching/index.html">CGAL dD spatial searching data structures</a>.
* It provides a simplified API to perform (approximate) nearest neighbor searches. Contrary to CGAL default behavior, the tree
* does not store the points themselves, but stores indices.
@@ -65,7 +65,7 @@ namespace spatial_searching {
* It must be a range whose iterator type is a `RandomAccessIterator`.
*/
template <typename K, typename Point_range>
-class Spatial_tree_data_structure
+class Kd_tree_search
{
typedef boost::iterator_property_map<
typename Point_range::const_iterator,
@@ -108,7 +108,7 @@ public:
/// \brief Constructor
/// @param[in] points Const reference to the point range. This range
/// is not copied, so it should not be destroyed or modified afterwards.
- Spatial_tree_data_structure(Point_range const& points)
+ Kd_tree_search(Point_range const& points)
: m_points(points),
m_tree(boost::counting_iterator<std::ptrdiff_t>(0),
boost::counting_iterator<std::ptrdiff_t>(points.size()),
@@ -125,7 +125,7 @@ public:
/// @param[in] only_these_points Specifies the indices of the points that
/// should be actually inserted into the tree. The other points are ignored.
template <typename Point_indices_range>
- Spatial_tree_data_structure(
+ Kd_tree_search(
Point_range const& points,
Point_indices_range const& only_these_points)
: m_points(points),
@@ -143,7 +143,7 @@ public:
/// is not copied, so it should not be destroyed or modified afterwards.
/// @param[in] begin_idx, past_the_end_idx Define the subset of the points that
/// should be actually inserted into the tree. The other points are ignored.
- Spatial_tree_data_structure(
+ Kd_tree_search(
Point_range const& points,
std::size_t begin_idx, std::size_t past_the_end_idx)
: m_points(points),
@@ -40,13 +40,13 @@ namespace spatial_searching {
*
* \details
- * The class Spatial_tree_data_structure is a tree-based data structure, based on
+ * The class Kd_tree_search is a tree-based data structure, based on
* <a target="_blank" href="http://doc.cgal.org/latest/Spatial_searching/index.html">CGAL dD spatial searching data structures</a>.
* It provides a simplified API to perform (approximate) nearest neighbor searches. Contrary to CGAL default behavior, the tree